`utils` module
**************

Fabric tasks
------------

.. autofunction:: django_fabfile.utils.cleanup_security_groups
.. autofunction:: django_fabfile.utils.update_volumes_tags

Internals
---------

.. automodule:: django_fabfile.utils
   :members:
